@@ -17,6 +17,7 @@
 
 
 import warnings
+from typing import Callable, Union
 
 from diffusers.configuration_utils import ConfigMixin, register_to_config
 from diffusers.schedulers.scheduling_utils import SchedulerMixin
@@ -132,11 +133,12 @@ class Mel(ConfigMixin, SchedulerMixin):
         """
         return self.sr
 
-    def audio_slice_to_image(self, slice: int) -> Image.Image:
+    def audio_slice_to_image(self, slice: int, ref: Union[float, Callable] = np.max) -> Image.Image:
         """Convert slice of audio to spectrogram.
 
         Args:
             slice (`int`): slice number of audio to convert (out of get_number_of_slices())
+            ref (`Union[float, Callable]`): reference value for spectrogram
 
         Returns:
             `PIL Image`: grayscale image of x_res x y_res
@@ -144,7 +146,7 @@ class Mel(ConfigMixin, SchedulerMixin):
         S = librosa.feature.melspectrogram(
             y=self.get_audio_slice(slice), sr=self.sr, n_fft=self.n_fft, hop_length=self.hop_length, n_mels=self.n_mels
         )
-        log_S = librosa.power_to_db(S, ref=np.max, top_db=self.top_db)
+        log_S = librosa.power_to_db(S, ref=ref, top_db=self.top_db)
         bytedata = (((log_S + self.top_db) * 255 / self.top_db).clip(0, 255) + 0.5).astype(np.uint8)
         image = Image.fromarray(bytedata)
         return image
